.. _getting_started:

===============
Getting started
===============

.. _installation:

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- start installation -->
   :end-before: <!-- end installation -->



Ways to use dhlab
~~~~~~~~~~~~~~~~~~~~~~~~~
* With the :doc:`Jupyter Notebooks <docs_notebooks>` visual interface
* Directly from a python console with the :doc:`API wrappers <usage_api>`


